@@ -10,9 +10,9 @@ __PACKAGE__->load_components(qw(TimeStamp));
 __PACKAGE__->table("customs");
 
 __PACKAGE__->add_columns(
-  "customs_id",
+  "id",
   { data_type => "varchar", is_nullable => 0, size => 255 },
-  "custom_data",
+  "data",
   { data_type => "text", is_nullable => 0 },
   "created",
   { data_type => "datetime", set_on_create => 1, is_nullable => 0 },
@@ -20,6 +20,6 @@ __PACKAGE__->add_columns(
   { data_type => "datetime", set_on_create => 1, is_nullable => 0 },
 );
 
-__PACKAGE__->set_primary_key("customs_id");
+__PACKAGE__->set_primary_key("id");
 
 1;
